@@ -30,6 +30,10 @@ from colorama import *
 
 
 
+try:
+    sys.path.insert(1, os.getcwd())
+except:
+    pass
 
 def run():
     """ Main routine which should be called on startup """
